@@ -19,7 +19,7 @@ my $has_PDL_stats_basic = $@ ? undef : 1;
 #  to hide the piddle from the caller to avoid arbitrary changes
 #  being applied to it.
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 our $Tolerance = 0.0;  #  for compatibility with Stats::Descr, but not used here
 
@@ -313,6 +313,10 @@ sub percentile {
 
     my $pctl = $self->_percentile($p);
 
+    if (blessed $pctl && $pctl->isa('PDL')) {
+        $pctl = $pctl->sclr;
+    }
+
     if (fmod ($p, 5) == 0) {
         $self->{_cache}{percentile}{$p} = $pctl;
     }
@@ -323,7 +327,7 @@ sub percentile {
 sub _percentile {
     my ($self, $p) = @_;
 
-    return $self->_get_piddle->pct($p / 100)->sclr;
+    return $self->_get_piddle->pct($p / 100);
 }
 
 
@@ -346,7 +350,7 @@ Statistics::Descriptive using PDL as the back-end
 
 =head1 VERSION
 
-Version 0.02
+Version 0.04
 
 =cut
 
