@@ -18,7 +18,7 @@ use PDL::NiceSlice;
 
 ## no critic (ProhibitExplicitReturnUndef)
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 use parent 'Statistics::Descriptive::PDL::Weighted';
 
@@ -156,12 +156,11 @@ __END__
 
 =head1 NAME
 
-Statistics::Descriptive::PDL::SampleWeighted -
-Sample weighted descriptive statistics using PDL as the back-end
+Statistics::Descriptive::PDL::SampleWeighted - Sample weighted descriptive statistics using PDL as the back-end
 
 =head1 VERSION
 
-Version 0.02
+Version 0.04
 
 =cut
 
